Tutorials
=========

Here we have select step-by-step guides to learn how to run examples of tuning calculations.

.. grid:: 1 1 2 2
   :gutter: 3

   .. grid-item-card:: Your First Electrostatic Tuning Map
      :link: first-tuning-map
      :link-type: doc

      Calculate HOMO tuning for a water molecule in under 5 minutes.

.. toctree::
   :maxdepth: 1
   :hidden:

   first-tuning-map